This page lists all documentation wiki pages for Google Mock **version 1.5.0** -- **if you use a different version of Google Mock, please read the documentation for that specific version instead.**

  * [ForDummies](V1_5_ForDummies.md) -- start here if you are new to Google Mock.
  * [CheatSheet](V1_5_CheatSheet.md) -- a quick reference.
  * [CookBook](V1_5_CookBook.md) -- recipes for doing various tasks using Google Mock.
  * [FrequentlyAskedQuestions](V1_5_FrequentlyAskedQuestions.md) -- check here before asking a question on the mailing list.

To contribute code to Google Mock, read:

  * DevGuide -- read this _before_ writing your first patch.
  * [Pump Manual](http://code.google.com/p/googletest/wiki/PumpManual) -- how we generate some of Google Mock's source files.